@@ -1,4 +1,4 @@
-//    Copyright (C) 2009 Dirk Vanden Boer <dirk.vdb@gmail.com>
+//    Copyright (C) 2010 Dirk Vanden Boer <dirk.vdb@gmail.com>
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -20,6 +20,9 @@
 #include <inttypes.h>
 #include <vector>
 
+namespace ffmpegthumbnailer
+{
+
 struct VideoFrame
 {
     VideoFrame()
@@ -35,4 +38,6 @@ struct VideoFrame
     std::vector<uint8_t> frameData;
 };
 
+}
+
 #endif
