@@ -18,7 +18,7 @@
 #define VIDEO_THUMBNAILERC_H
 
 #include <inttypes.h>
-#include "imagetypes.h"
+#include "ffmpegthumbnailertypes.h"
 
 #ifdef __cplusplus
 extern "C"
@@ -26,21 +26,24 @@ extern "C"
 #endif
 
 struct AVFormatContext;
+struct thumbnailer_data;
+
+typedef void(*thumbnailer_log_callback)(ThumbnailerLogLevel, const char*);
 
 typedef struct video_thumbnailer_struct
 {
-    int                     thumbnail_size;         /* default = 128 */
-    int                     seek_percentage;        /* default = 10 */
-    char*                   seek_time;              /* default = NULL (format hh:mm:ss, overrides seek_percentage if set) */
-    int                     overlay_film_strip;     /* default = 0 */
-    int                     workaround_bugs;        /* default = 0 */
-    int                     thumbnail_image_quality;/* default = 8 (0 is bad, 10 is best)*/
-    ThumbnailerImageType    thumbnail_image_type;   /* default = Png */
-    struct AVFormatContext* av_format_context;      /* default = NULL */
-    int                     maintain_aspect_ratio;  /* default = 1 */
+    int                         thumbnail_size;             /* default = 128 */
+    int                         seek_percentage;            /* default = 10 */
+    char*                       seek_time;                  /* default = NULL (format hh:mm:ss, overrides seek_percentage if set) */
+    int                         overlay_film_strip;         /* default = 0 */
+    int                         workaround_bugs;            /* default = 0 */
+    int                         thumbnail_image_quality;    /* default = 8 (0 is bad, 10 is best)*/
+    ThumbnailerImageType        thumbnail_image_type;       /* default = Png */
+    struct AVFormatContext*     av_format_context;          /* default = NULL */
+    int                         maintain_aspect_ratio;      /* default = 1 */
+    int                         prefer_embedded_metadata;   /* default = 0 */
 
-    void*                   thumbnailer;            /* for internal use only */
-    void*                   filter;                 /* for internal use only */
+    struct thumbnailer_data*    tdata;                      /* for internal use only */
 } video_thumbnailer;
 
 typedef struct image_data_struct
@@ -65,6 +68,9 @@ void video_thumbnailer_destroy_image_data(image_data* data);
 int video_thumbnailer_generate_thumbnail_to_buffer(video_thumbnailer* thumbnailer, const char* movie_filename, image_data* generated_image_data);
 /* generate thumbnail from video file (movie_filename), image is written to output_fileName on disk*/
 int video_thumbnailer_generate_thumbnail_to_file(video_thumbnailer* thumbnailer, const char* movie_filename, const char* output_fileName);
+/* install a logging callback that gets called on errors and informational messages, reset by passing NULL.
+   by default no logging is generated on stdout or stderr */
+void video_thumbnailer_set_log_callback(video_thumbnailer* thumbnailer, thumbnailer_log_callback cb);
 
 #ifdef __cplusplus
 }
